## v0.2.1 (2025-06-28)

### Fix

- force bump

## v0.2.0 (2025-06-28)

### Feat

- update week 8 notebooks
- complete rewrite (unstable state)
- add script and notebook for working with aeon-toolkit preprocessing
- run week 8/toy_model.ipynb
- add dataset package for preprocessing and aggregating races across whole season
- working on data preprocessor

### Fix

- update __init__

### Refactor

- rename capstone to f1_etl
- break f1-etl main module into smaller files
